==> gradle-0.7-all.zip: gradle-0.7/src/org/gradle/api/internal/artifacts/DefaultResolverContainer.java <==
/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts;

import groovy.lang.Closure;
import org.apache.ivy.plugins.resolver.DependencyResolver;
import org.gradle.api.InvalidUserDataException;
import org.gradle.api.Task;
import org.gradle.api.UnknownDomainObjectException;
import org.gradle.api.artifacts.ResolverContainer;
import org.gradle.api.artifacts.ConfigurationContainer;
import org.gradle.api.artifacts.UnknownRepositoryException;
import org.gradle.api.artifacts.maven.Conf2ScopeMappingContainer;
import org.gradle.api.artifacts.maven.GroovyMavenDeployer;
import org.gradle.api.artifacts.maven.MavenResolver;
import org.gradle.api.internal.ConventionAwareHelper;
import org.gradle.api.internal.DefaultDomainObjectContainer;
import org.gradle.api.internal.IConventionAware;
import org.gradle.api.internal.artifacts.ivyservice.ResolverFactory;
import org.gradle.api.plugins.Convention;
import org.gradle.api.tasks.ConventionValue;
import org.gradle.util.ConfigureUtil;
import org.gradle.util.GUtil;

import java.io.File;
import java.util.*;

/**
 * @author Hans Dockter
 */
public class DefaultResolverContainer extends DefaultDomainObjectContainer<DependencyResolver>
        implements ResolverContainer, IConventionAware {
    private ConventionAwareHelper conventionAwareHelper;

    private ResolverFactory resolverFactory;

    private List<String> resolverNames = new ArrayList<String>();

    private File mavenPomDir = null;

    private Conf2ScopeMappingContainer mavenScopeMappings = null;

    private ConfigurationContainer configurationContainer = null;

    public DefaultResolverContainer(ResolverFactory resolverFactory, Convention convention) {
        super(DependencyResolver.class);
        this.resolverFactory = resolverFactory;
        conventionAwareHelper = new ConventionAwareHelper(this);
        conventionAwareHelper.setConvention(convention);
    }

    @Override
    public String getDisplayName() {
        return "resolver container";
    }

    public DependencyResolver add(Object userDescription) {
        return add(userDescription, null);
    }

    public DependencyResolver add(Object userDescription, Closure configureClosure) {
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                resolverNames.add(resolverName);
            }
        });
    }

    public DependencyResolver addBefore(Object userDescription, String afterResolverName) {
        return addBefore(userDescription, afterResolverName, null);
    }

    public DependencyResolver addBefore(Object userDescription, final String afterResolverName, Closure configureClosure) {
        if (!GUtil.isTrue(afterResolverName)) {
            throw new InvalidUserDataException("You must specify userDescription and afterResolverName");
        }
        if (findByName(afterResolverName) == null) {
            throw new InvalidUserDataException("Resolver $afterResolverName does not exists!");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                resolverNames.add(resolverNames.indexOf(afterResolverName), resolverName);
            }
        });
    }

    public DependencyResolver addAfter(Object userDescription, final String beforeResolverName) {
        return addAfter(userDescription, beforeResolverName, null);
    }

    public DependencyResolver addAfter(Object userDescription, final String beforeResolverName, Closure configureClosure) {
        if (!GUtil.isTrue(beforeResolverName)) {
            throw new InvalidUserDataException("You must specify userDescription and beforeResolverName");
        }
        if (findByName(beforeResolverName) == null) {
            throw new InvalidUserDataException("Resolver $beforeResolverName does not exists!");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                int insertPos = resolverNames.indexOf(beforeResolverName) + 1;
                if (insertPos == resolverNames.size()) {
                    resolverNames.add(resolverName);
                } else {
                    resolverNames.add(insertPos, resolverName);
                }
            }
        });
    }

    public DependencyResolver addFirst(Object userDescription) {
        return addFirst(userDescription, null);
    }

    public DependencyResolver addFirst(Object userDescription, Closure configureClosure) {
        if (!GUtil.isTrue(userDescription)) {
            throw new InvalidUserDataException("You must specify userDescription");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                if (resolverNames.size() == 0) {
                    resolverNames.add(resolverName);
                } else {
                    resolverNames.add(0, resolverName);
                }
            }
        });
    }

    private DependencyResolver addInternal(Object userDescription, Closure configureClosure, OrderAction orderAction) {
        if (!GUtil.isTrue(userDescription)) {
            throw new InvalidUserDataException("You must specify userDescription");
        }
        DependencyResolver resolver = resolverFactory.createResolver(userDescription);
        ConfigureUtil.configure(configureClosure, resolver);
        if (!GUtil.isTrue(resolver.getName())) {
            throw new InvalidUserDataException("You must specify a name for the resolver. Resolver=" + userDescription);
        }
        if (findByName(resolver.getName()) != null) {
            throw new InvalidUserDataException(String.format(
                    "Cannot add a resolver with name '%s' as a resolver with that name already exists.", resolver.getName()));
        }
        addObject(resolver.getName(), resolver);
        orderAction.apply(resolver.getName());
        return resolver;
    }

    @Override
    protected UnknownDomainObjectException createNotFoundException(String name) {
        return new UnknownRepositoryException(String.format("Repository with name '%s' not found.", name));
    }

    public List<DependencyResolver> getResolvers() {
        List<DependencyResolver> returnedResolvers = new ArrayList<DependencyResolver>();
        for (String resolverName : resolverNames) {
            returnedResolvers.add(getByName(resolverName));
        }
        return returnedResolvers;
    }

    private static interface OrderAction {
        
        void apply(String resolverName);
    }

    public ResolverFactory getResolverFactory() {
        return resolverFactory;
    }

    public void setResolverFactory(ResolverFactory resolverFactory) {
        this.resolverFactory = resolverFactory;
    }

    public List<String> getResolverNames() {
        return resolverNames;
    }

    public void setResolverNames(List<String> resolverNames) {
        this.resolverNames = resolverNames;
    }

    public ConfigurationContainer getConfigurationContainer() {
        return (ConfigurationContainer) conv(configurationContainer, "configurationContainer");
    }

    public void setConfigurationContainer(ConfigurationContainer configurationContainer) {
        this.configurationContainer = configurationContainer;
    }

    public GroovyMavenDeployer createMavenDeployer(String name) {
        return resolverFactory.createMavenDeployer(name, getMavenPomDir(), getConfigurationContainer(), getMavenScopeMappings());
    }

    public MavenResolver createMavenInstaller(String name) {
        return resolverFactory.createMavenInstaller(name, getMavenPomDir(), getConfigurationContainer(), getMavenScopeMappings());
    }

    public Object conventionMapping(Map<String, ConventionValue> mapping) {
        return conventionAwareHelper.conventionMapping(mapping);
    }

    public Object conventionProperty(String name) {
        return conventionAwareHelper.getConventionValue(name);
    }

    public void setConventionMapping(Map<String, ConventionValue> conventionMapping) {
        conventionAwareHelper.setConventionMapping(conventionMapping);
    }

    public Map<String, ConventionValue> getConventionMapping() {
        return conventionAwareHelper.getConventionMapping();
    }

    public ConventionAwareHelper getConventionAwareHelper() {
        return conventionAwareHelper;
    }

    public void setConventionAwareHelper(ConventionAwareHelper conventionAwareHelper) {
        this.conventionAwareHelper = conventionAwareHelper;
    }

    public Object conv(Object internalValue, String propertyName) {
        return conventionAwareHelper.getConventionValue(internalValue, propertyName);
    }

    public Conf2ScopeMappingContainer getMavenScopeMappings() {
        return (Conf2ScopeMappingContainer) conv(mavenScopeMappings, "mavenScopeMappings");
    }

    public void setMavenScopeMappings(Conf2ScopeMappingContainer mavenScopeMappings) {
        this.mavenScopeMappings = mavenScopeMappings;
    }

    public File getMavenPomDir() {
        return (File) conv(mavenPomDir, "mavenPomDir");
    }

    public void setMavenPomDir(File mavenPomDir) {
        this.mavenPomDir = mavenPomDir;
    }
}

==> gradle-0.8-all.zip: gradle-0.8/src/org/gradle/api/internal/artifacts/DefaultResolverContainer.java <==
/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts;

import groovy.lang.Closure;
import org.apache.ivy.plugins.resolver.DependencyResolver;
import org.gradle.api.InvalidUserDataException;
import org.gradle.api.UnknownDomainObjectException;
import org.gradle.api.artifacts.ConfigurationContainer;
import org.gradle.api.artifacts.ResolverContainer;
import org.gradle.api.artifacts.UnknownRepositoryException;
import org.gradle.api.artifacts.maven.Conf2ScopeMappingContainer;
import org.gradle.api.artifacts.maven.GroovyMavenDeployer;
import org.gradle.api.artifacts.maven.MavenResolver;
import org.gradle.api.internal.DefaultDomainObjectContainer;
import org.gradle.api.internal.artifacts.ivyservice.ResolverFactory;
import org.gradle.util.ConfigureUtil;
import org.gradle.util.GUtil;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Hans Dockter
 */
public class DefaultResolverContainer extends DefaultDomainObjectContainer<DependencyResolver>
        implements ResolverContainer {
    private ResolverFactory resolverFactory;

    private List<String> resolverNames = new ArrayList<String>();

    private File mavenPomDir = null;

    private Conf2ScopeMappingContainer mavenScopeMappings = null;

    private ConfigurationContainer configurationContainer = null;

    public DefaultResolverContainer(ResolverFactory resolverFactory) {
        super(DependencyResolver.class);
        this.resolverFactory = resolverFactory;
    }

    @Override
    public String getTypeDisplayName() {
        return "resolver";
    }

    public DependencyResolver add(Object userDescription) {
        return add(userDescription, null);
    }

    public DependencyResolver add(Object userDescription, Closure configureClosure) {
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                resolverNames.add(resolverName);
            }
        });
    }

    public DependencyResolver addBefore(Object userDescription, String afterResolverName) {
        return addBefore(userDescription, afterResolverName, null);
    }

    public DependencyResolver addBefore(Object userDescription, final String afterResolverName, Closure configureClosure) {
        if (!GUtil.isTrue(afterResolverName)) {
            throw new InvalidUserDataException("You must specify userDescription and afterResolverName");
        }
        if (findByName(afterResolverName) == null) {
            throw new InvalidUserDataException("Resolver $afterResolverName does not exists!");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                resolverNames.add(resolverNames.indexOf(afterResolverName), resolverName);
            }
        });
    }

    public DependencyResolver addAfter(Object userDescription, final String beforeResolverName) {
        return addAfter(userDescription, beforeResolverName, null);
    }

    public DependencyResolver addAfter(Object userDescription, final String beforeResolverName, Closure configureClosure) {
        if (!GUtil.isTrue(beforeResolverName)) {
            throw new InvalidUserDataException("You must specify userDescription and beforeResolverName");
        }
        if (findByName(beforeResolverName) == null) {
            throw new InvalidUserDataException("Resolver $beforeResolverName does not exists!");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                int insertPos = resolverNames.indexOf(beforeResolverName) + 1;
                if (insertPos == resolverNames.size()) {
                    resolverNames.add(resolverName);
                } else {
                    resolverNames.add(insertPos, resolverName);
                }
            }
        });
    }

    public DependencyResolver addFirst(Object userDescription) {
        return addFirst(userDescription, null);
    }

    public DependencyResolver addFirst(Object userDescription, Closure configureClosure) {
        if (!GUtil.isTrue(userDescription)) {
            throw new InvalidUserDataException("You must specify userDescription");
        }
        return addInternal(userDescription, configureClosure, new OrderAction() {
            public void apply(String resolverName) {
                if (resolverNames.size() == 0) {
                    resolverNames.add(resolverName);
                } else {
                    resolverNames.add(0, resolverName);
                }
            }
        });
    }

    private DependencyResolver addInternal(Object userDescription, Closure configureClosure, OrderAction orderAction) {
        if (!GUtil.isTrue(userDescription)) {
            throw new InvalidUserDataException("You must specify userDescription");
        }
        DependencyResolver resolver = resolverFactory.createResolver(userDescription);
        ConfigureUtil.configure(configureClosure, resolver);
        if (!GUtil.isTrue(resolver.getName())) {
            throw new InvalidUserDataException("You must specify a name for the resolver. Resolver=" + userDescription);
        }
        if (findByName(resolver.getName()) != null) {
            throw new InvalidUserDataException(String.format(
                    "Cannot add a resolver with name '%s' as a resolver with that name already exists.", resolver.getName()));
        }
        addObject(resolver.getName(), resolver);
        orderAction.apply(resolver.getName());
        return resolver;
    }

    @Override
    protected UnknownDomainObjectException createNotFoundException(String name) {
        return new UnknownRepositoryException(String.format("Repository with name '%s' not found.", name));
    }

    public List<DependencyResolver> getResolvers() {
        List<DependencyResolver> returnedResolvers = new ArrayList<DependencyResolver>();
        for (String resolverName : resolverNames) {
            returnedResolvers.add(getByName(resolverName));
        }
        return returnedResolvers;
    }

    private static interface OrderAction {
        
        void apply(String resolverName);
    }

    public ResolverFactory getResolverFactory() {
        return resolverFactory;
    }

    public void setResolverFactory(ResolverFactory resolverFactory) {
        this.resolverFactory = resolverFactory;
    }

    public List<String> getResolverNames() {
        return resolverNames;
    }

    public void setResolverNames(List<String> resolverNames) {
        this.resolverNames = resolverNames;
    }

    public ConfigurationContainer getConfigurationContainer() {
        return configurationContainer;
    }

    public void setConfigurationContainer(ConfigurationContainer configurationContainer) {
        this.configurationContainer = configurationContainer;
    }

    public GroovyMavenDeployer createMavenDeployer(String name) {
        return resolverFactory.createMavenDeployer(name, getMavenPomDir(), getConfigurationContainer(), getMavenScopeMappings());
    }

    public MavenResolver createMavenInstaller(String name) {
        return resolverFactory.createMavenInstaller(name, getMavenPomDir(), getConfigurationContainer(), getMavenScopeMappings());
    }

    public Conf2ScopeMappingContainer getMavenScopeMappings() {
        return mavenScopeMappings;
    }

    public void setMavenScopeMappings(Conf2ScopeMappingContainer mavenScopeMappings) {
        this.mavenScopeMappings = mavenScopeMappings;
    }

    public File getMavenPomDir() {
        return mavenPomDir;
    }

    public void setMavenPomDir(File mavenPomDir) {
        this.mavenPomDir = mavenPomDir;
    }
}
